LookupInfo

Struct LookupInfo 

pub struct LookupInfo {
    pub max_per_row: usize,
    pub max_joint_size: u32,
    pub features: LookupFeatures,
}
Describes the desired lookup configuration.

Fields

max_per_row: usize

The maximum length of an element of kinds. This can be computed from kinds.

max_joint_size: u32

The maximum joint size of any joint lookup in a constraint in kinds. This can be computed from kinds.

features: LookupFeatures

The features enabled for this lookup configuration

Implementations

Source

impl LookupInfo

pub fn new( max_per_row: usize, max_joint_size: u32, features: LookupFeatures, ) -> LookupInfo

Source

impl LookupInfo

pub fn create(features: LookupFeatures) -> Self

Create the default lookup configuration.

pub fn create_from_gates<F: PrimeField>( gates: &[CircuitGate<F>], uses_runtime_tables: bool, ) -> Option<Self>

pub fn selector_polynomials_and_tables<F: PrimeField>( &self, domain: &EvaluationDomains<F>, gates: &[CircuitGate<F>], ) -> (LookupSelectors<Evaluations<F, Radix2EvaluationDomain<F>>>, Vec<LookupTable<F>>)

Each entry in kinds has a corresponding selector polynomial that controls whether that lookup kind should be enforced at a given row. This computes those selector polynomials.

pub fn by_row<F: PrimeField>( &self, gates: &[CircuitGate<F>], ) -> Vec<Vec<JointLookupSpec<F>>>

For each row in the circuit, which lookup-constraints should be enforced at that row.