pub struct ForeignFieldMul<F>(PhantomData<F>);Expand description
- This gate operates on the Curr and Next rows
- It uses copy, plookup, crumb and custom constraints
Tuple Fields
0: PhantomData<F>Trait Implementations
Sourceimpl<F> Argument<F> for ForeignFieldMul<F>where
F: PrimeField,
impl<F> Argument<F> for ForeignFieldMul<F>where
F: PrimeField,
Sourceconst ARGUMENT_TYPE: ArgumentType
const ARGUMENT_TYPE: ArgumentType
The type of constraints that this will produce.
This is important to enforce that we don’t combine the constraints
with powers of alpha that collide with other mutually inclusive arguments.
Sourceconst CONSTRAINTS: u32 = 11
const CONSTRAINTS: u32 = 11
The number of constraints created by the argument.
Sourcefn constraint_checks<T: ExprOps<F, BerkeleyChallengeTerm>>(
env: &ArgumentEnv<F, T>,
_cache: &mut Cache,
) -> Vec<T>
fn constraint_checks<T: ExprOps<F, BerkeleyChallengeTerm>>( env: &ArgumentEnv<F, T>, _cache: &mut Cache, ) -> Vec<T>
Constraints for this argument
Sourceimpl<F: Default> Default for ForeignFieldMul<F>
impl<F: Default> Default for ForeignFieldMul<F>
Sourcefn default() -> ForeignFieldMul<F>
fn default() -> ForeignFieldMul<F>
Returns the “default value” for a type. Read more