LookupContext

Struct LookupContext 

struct LookupContext<G, F>
where G: CommitmentCurve, F: FftField,
{
Show 19 fields joint_combiner: Option<F>, table_id_combiner: Option<F>, dummy_lookup_value: Option<F>, joint_lookup_table: Option<DensePolynomial<F>>, joint_lookup_table_d8: Option<Evaluations<F, Radix2EvaluationDomain<F>>>, sorted: Option<Vec<Evaluations<F, Radix2EvaluationDomain<F>>>>, sorted_coeffs: Option<Vec<DensePolynomial<F>>>, sorted_comms: Option<Vec<BlindedCommitment<G>>>, sorted8: Option<Vec<Evaluations<F, Radix2EvaluationDomain<F>>>>, aggreg_coeffs: Option<DensePolynomial<F>>, aggreg_comm: Option<BlindedCommitment<G>>, aggreg8: Option<Evaluations<F, Radix2EvaluationDomain<F>>>, pub lookup_aggregation_eval: Option<PointEvaluations<Vec<F>>>, pub lookup_table_eval: Option<PointEvaluations<Vec<F>>>, pub lookup_sorted_eval: [Option<PointEvaluations<Vec<F>>>; 5], pub runtime_lookup_table_eval: Option<PointEvaluations<Vec<F>>>, runtime_table: Option<DensePolynomial<F>>, runtime_table_d8: Option<Evaluations<F, Radix2EvaluationDomain<F>>>, runtime_table_comm: Option<BlindedCommitment<G>>,
}
Contains variables needed for lookup in the prover algorithm.

Fields

joint_combiner: Option<F>

The joint combiner used to join the columns of lookup tables

table_id_combiner: Option<F>

The power of the joint_combiner that can be used to add a table_id column to the concatenated lookup tables.

dummy_lookup_value: Option<F>

The combined lookup entry that can be used as dummy value

joint_lookup_table: Option<DensePolynomial<F>>

The combined lookup table

joint_lookup_table_d8: Option<Evaluations<F, Radix2EvaluationDomain<F>>>sorted: Option<Vec<Evaluations<F, Radix2EvaluationDomain<F>>>>

The sorted polynomials s in different forms

sorted_coeffs: Option<Vec<DensePolynomial<F>>>sorted_comms: Option<Vec<BlindedCommitment<G>>>sorted8: Option<Vec<Evaluations<F, Radix2EvaluationDomain<F>>>>aggreg_coeffs: Option<DensePolynomial<F>>

The aggregation polynomial in different forms

aggreg_comm: Option<BlindedCommitment<G>>aggreg8: Option<Evaluations<F, Radix2EvaluationDomain<F>>>lookup_aggregation_eval: Option<PointEvaluations<Vec<F>>>

evaluation of lookup aggregation polynomial

lookup_table_eval: Option<PointEvaluations<Vec<F>>>

evaluation of lookup table polynomial

lookup_sorted_eval: [Option<PointEvaluations<Vec<F>>>; 5]

evaluation of lookup sorted polynomials

runtime_lookup_table_eval: Option<PointEvaluations<Vec<F>>>

evaluation of runtime lookup table polynomial

runtime_table: Option<DensePolynomial<F>>

Runtime table

runtime_table_d8: Option<Evaluations<F, Radix2EvaluationDomain<F>>>runtime_table_comm: Option<BlindedCommitment<G>>